package config

const (
	DoubleClickThreshold = 400 // How many milliseconds to wait before a second click is not a double click
)

var Bindings map[string]string

func init() {
	Bindings = make(map[string]string)
}
